>From 3c8eee65495753b79c4bd1b3d10d92f91e80e33f Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Sun, 21 Aug 2011 00:24:59 +0300
Subject: [carFl mem 51/65] Move chip_to_probe to globals struct

Move this variable to globals structure.

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 cli_classic.c |   14 +++++++-------
 flash.h       |    2 +-
 flashrom.c    |    5 +++--
 w29ee011.c    |    2 +-
 4 files changed, 12 insertions(+), 11 deletions(-)

diff --git a/cli_classic.c b/cli_classic.c
index cd4014b..71b9469 100644
--- a/cli_classic.c
+++ b/cli_classic.c
@@ -192,7 +192,7 @@ int cli_classic(globals *g, int argc, char *argv[])
 			dont_verify_it = 1;
 			break;
 		case 'c':
-			chip_to_probe = strdup(optarg);
+			g->chip_to_probe = strdup(optarg);
 			break;
 		case 'V':
 			verbose++;
@@ -339,13 +339,13 @@ int cli_classic(globals *g, int argc, char *argv[])
 	}
 #endif
 
-	if (chip_to_probe) {
+	if (g->chip_to_probe) {
 		for (flash = flashchips; flash && flash->name; flash++)
-			if (!strcmp(flash->name, chip_to_probe))
+			if (!strcmp(flash->name, g->chip_to_probe))
 				break;
 		if (!flash || !flash->name) {
 			fprintf(stderr, "Error: Unknown chip '%s' specified.\n",
-				chip_to_probe);
+				g->chip_to_probe);
 			printf("Run flashrom -L to view the hardware supported "
 			       "in this flashrom version.\n");
 			exit(1);
@@ -382,17 +382,17 @@ int cli_classic(globals *g, int argc, char *argv[])
 		goto out_shutdown;
 	} else if (!chipcount) {
 		printf("No EEPROM/flash device found.\n");
-		if (!force || !chip_to_probe) {
+		if (!force || !g->chip_to_probe) {
 			printf("Note: flashrom can never write if the flash "
 			       "chip isn't found automatically.\n");
 		}
-		if (force && read_it && chip_to_probe) {
+		if (force && read_it && g->chip_to_probe) {
 			printf("Force read (-f -r -c) requested, pretending "
 			       "the chip is there:\n");
 			startchip = probe_flash(g, 0, &flashes[0], 1);
 			if (startchip == -1) {
 				printf("Probing for flash chip '%s' failed.\n",
-				       chip_to_probe);
+				       g->chip_to_probe);
 				ret = 1;
 				goto out_shutdown;
 			}
diff --git a/flash.h b/flash.h
index 6c8f1dc..52698de 100644
--- a/flash.h
+++ b/flash.h
@@ -207,7 +207,6 @@ enum write_granularity {
 };
 extern int verbose;
 extern const char flashrom_version[];
-extern char *chip_to_probe;
 void map_flash_registers(globals *g, struct flashchip *flash);
 int read_memmapped(globals *g, struct flashchip *flash, uint8_t *buf, int start, int len);
 int erase_flash(struct flashchip *flash);
@@ -296,6 +295,7 @@ struct globals {
 	uint8_t *undo_data_free_ptr; //pointer to free space (for new undo data)
 	char tmp_buf[TMP_BUF_SIZE]; // for extract programmer param
 
+	char *chip_to_probe;
 	/* Supported buses for the current programmer. */
 	enum chipbustype buses_supported;
 };
diff --git a/flashrom.c b/flashrom.c
index f4d763b..9e4ee80 100644
--- a/flashrom.c
+++ b/flashrom.c
@@ -39,7 +39,6 @@
 #include "programmer.h"
 
 const char flashrom_version[] = "carFl";
-char *chip_to_probe = NULL;
 int verbose = 0;
 
 void init_globals(globals *g)
@@ -52,6 +51,8 @@ void init_globals(globals *g)
 	#error Please enable either CONFIG_DUMMY or CONFIG_INTERNAL
 	#endif
 	g->undo_data_free_ptr = g->undo_data_buf;
+
+	g->chip_to_probe = NULL;
 }
 
 static char *programmer_param = NULL;
@@ -1072,7 +1073,7 @@ int probe_flash(globals *g, int startchip, struct flashchip *fill_flash, int for
 	char *tmp;
 
 	for (flash = flashchips + startchip; flash && flash->name; flash++) {
-		if (chip_to_probe && strcmp(flash->name, chip_to_probe) != 0)
+		if (g->chip_to_probe && strcmp(flash->name, g->chip_to_probe) != 0)
 			continue;
 		buses_common = g->buses_supported & flash->bustype;
 		if (!buses_common) {
diff --git a/w29ee011.c b/w29ee011.c
index ca397e2..2639c42 100644
--- a/w29ee011.c
+++ b/w29ee011.c
@@ -30,7 +30,7 @@ int probe_w29ee011(globals *g, struct flashchip *flash)
 	chipaddr bios = flash->virtual_memory;
 	uint8_t id1, id2;
 
-	if (!chip_to_probe || strcmp(chip_to_probe, flash->name)) {
+	if (!g->chip_to_probe || strcmp(g->chip_to_probe, flash->name)) {
 		msg_cdbg("Old Winbond W29* probe method disabled because "
 			 "the probing sequence puts the AMIC A49LF040A in "
 			 "a funky state. Use 'flashrom -c %s' if you "
-- 
1.7.6

